@@ -28,12 +28,26 @@ autodoc_mock_imports = [
     'torch'
 ]
 extensions = [
-  'sphinx.ext.autodoc',
-  'sphinx.ext.napoleon',
-  'sphinx.ext.linkcode',
-  'sphinx.ext.todo',
-  'myst_parser'
+    'myst_parser',
+    'sphinx.ext.autodoc',
+    'sphinx.ext.linkcode',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.todo'
 ]
+index_entries = [
+]
+
+
+def skip(_app, _what, name, _obj, would_skip, _options):  # pylint: disable=too-many-arguments
+    '''Customize autodoc member skipping.'''
+    if name == '__init__':
+        return False
+    return would_skip
+
+
+def setup(app):
+    '''Connect the skip function.'''
+    app.connect('autodoc-skip-member', skip)
 
 
 def linkcode_resolve(domain, info):
